%define name	upower
%define oname	UPower
%define version	0.9.15
%define release	%mkrel 2

%define major 1
%define libname %mklibname upower-glib %major
%define develname %mklibname -d upower-glib

%define gi_major 1.0
%define girname %mklibname %name-gir %gi_major

%define git_url git://anongit.freedesktop.org/DeviceKit/upower

%define _with_systemd 1

Name: %name
Version: %version
Release: %release
Summary: Power Management Service
License: GPLv2+
Group: System/Kernel and hardware
URL:     http://upower.freedesktop.org/
Source0: http://upower.freedesktop.org/releases/%{name}-%{version}.tar.xz
Source1: upowerd.service
Provides: %{oname} = %{version}-%{release}
BuildRequires: libgudev-devel
BuildRequires: glib2-devel 
BuildRequires: dbus-devel 
BuildRequires: dbus-glib-devel
BuildRequires: polkit-1-devel >= 0.91
BuildRequires: sqlite-devel
BuildRequires: libtool
BuildRequires: intltool
BuildRequires: gettext
BuildRequires: libusb-devel
BuildRequires: libxslt-proc
BuildRequires: docbook-style-xsl
BuildRequires: gtk-doc >= 1.3
BuildRequires: gobject-introspection-devel
BuildRequires: pkgconfig(libimobiledevice-1.0) >= 0.9.7
BuildRequires: pkgconfig(libplist) >= 0.12

%if %{_with_systemd}
BuildRequires: systemd-units
%endif

Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
Requires:  pm-utils
Requires:  suspend
Obsoletes: devicekit-power
Provides:  devicekit-power

%description
%{oname} provides a daemon, API and command line tools for
managing power devices attached to the system.

%package -n %libname
Summary: Shared Library of %{oname}
Group: System/Libraries
Requires: %name >= %version-%release

%description -n %libname
%{oname} provides a daemon, API and command line tools for
managing power devices attached to the system.


%package -n %develname
Summary: Headers and libraries for %{oname}
Group: Development/C
Provides: %{oname}-devel = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}
Requires: %{name} = %{version}
Requires: %libname = %version-%release
#gw libtool dep
Requires: libusb-devel

%description -n %develname
Headers and libraries for %{oname}

%package -n %{girname}
Summary:        GObject Introspection interface description for %name
Group:          System/Libraries
Requires:       %{libname} = %{version}-%{release}

%description -n %{girname}
GObject Introspection interface description for %name.

%prep
%setup -q 
%apply_patches

%build
%configure2_5x --enable-gtk-doc --disable-static
%make

%install
rm -rf %{buildroot}
%makeinstall_std

# Remove .la files
rm -fr %buildroot%{_libdir}/*.la

%if %{_with_systemd}
mkdir -p %{buildroot}%{_unitdir}
install -m 0644 -D %{SOURCE1} %{buildroot}%{_unitdir}/upowerd.service
sed -i 's!@LIB@!%_libdir/!' %{buildroot}%{_unitdir}/upowerd.service
%endif

%find_lang %name


%if %{_with_systemd}
%post
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ "$1" -ge 1 ]; then
/bin/systemctl enable upowerd.service >/dev/null 2>&1 || :
/bin/systemctl try-restart upowerd.service >/dev/null 2>&1 || :
fi

%postun
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ "$1" -ge 1 ] ; then
/bin/systemctl try-restart upowerd.service >/dev/null 2>&1 || :
fi

%preun
if [ "$1" = "0" ]; then
/bin/systemctl --no-reload upowerd.service > /dev/null 2>&1 || :
/bin/systemctl stop upowerd.service > /dev/null 2>&1 || :
fi
%endif

%files -f %name.lang
%doc README AUTHORS NEWS HACKING
%dir %_sysconfdir/UPower/
%config(noreplace) %_sysconfdir/UPower/UPower.conf
%{_sysconfdir}/dbus-1/system.d/*.conf
/lib/udev/rules.d/*.rules
%dir %{_localstatedir}/lib/upower

%{_bindir}/*
%{_libdir}/upowerd

%{_mandir}/man1/*
%{_mandir}/man7/*
%{_mandir}/man8/*

%{_datadir}/polkit-1/actions/*.policy
%{_datadir}/dbus-1/system-services/*.service

%if %{_with_systemd}
%{_unitdir}/upowerd.service
%endif

%files -n %libname
%{_libdir}/libupower-glib.so.%{major}*

%files -n %girname
%{_libdir}/girepository-1.0/UPowerGlib-%gi_major.typelib

%files -n %develname
%{_datadir}/dbus-1/interfaces/*.xml
%dir %{_datadir}/gtk-doc/html/UPower
%{_datadir}/gtk-doc/html/UPower/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/upower-glib.pc
%{_datadir}/gir-1.0/UPowerGlib-1.0.gir
%{_includedir}/libupower-glib


%changelog

* Sat Apr 28 2012 tmb <tmb> 0.9.15-2.mga2
+ Revision: 233893
- Require rpm-helper >= 0.24.8-1 for systemd support

  + dmorgan <dmorgan>
    - Add suspend as requires

* Sat Jan 28 2012 tv <tv> 0.9.15-1.mga2
+ Revision: 202447
- new release

* Thu Dec 08 2011 dmorgan <dmorgan> 0.9.14-11.mga2
+ Revision: 178959
- Create missing %%{_localstatedir}/lib/upower folder

* Fri Nov 04 2011 dmorgan <dmorgan> 0.9.14-10.mga2
+ Revision: 162976
- Fix upowerd in systemd service file

* Tue Nov 01 2011 dmorgan <dmorgan> 0.9.14-9.mga2
+ Revision: 160955
- Fix scriplets ( mdv)

* Sun Oct 30 2011 blino <blino> 0.9.14-8.mga2
+ Revision: 159915
- do not require systemd in post, basesystem should have already taken care of that

* Sat Oct 29 2011 dmorgan <dmorgan> 0.9.14-7.mga2
+ Revision: 159677
- Fix scriplets
- Try to fix systemd support

* Thu Oct 13 2011 dmorgan <dmorgan> 0.9.14-5.mga2
+ Revision: 154182
- Disable systemd support for the moment

* Wed Oct 12 2011 dmorgan <dmorgan> 0.9.14-3.mga2
+ Revision: 154157
- Fix typo in if statement

* Wed Oct 12 2011 dmorgan <dmorgan> 0.9.14-2.mga2
+ Revision: 154115
- Add systemd support

* Tue Oct 11 2011 tv <tv> 0.9.14-1.mga2
+ Revision: 153957
- new release
- drop patch 0 (merge)

* Thu Sep 29 2011 mikala <mikala> 0.9.13-2.mga2
+ Revision: 150213
- Add patch0 from upstream ( filter all debug messages unless --verbose is used)

* Thu Sep 08 2011 wally <wally> 0.9.13-1.mga2
+ Revision: 141469
- new version 0.9.13
- enable imobiledevice support

* Thu Jul 07 2011 dmorgan <dmorgan> 0.9.12-2.mga2
+ Revision: 119832
- Split gir files outside lib package

* Mon Jul 04 2011 dmorgan <dmorgan> 0.9.12-1.mga2
+ Revision: 118492
- New version 0.9.12

* Wed Jun 08 2011 dmorgan <dmorgan> 0.9.11-1.mga2
+ Revision: 101752
- New version 0.9.11

* Wed Apr 13 2011 tv <tv> 0.9.9-1.mga1
+ Revision: 84185
- no more devkit-power-daemon
- new release

* Thu Jan 20 2011 pterjan <pterjan> 0.9.8-1.mga1
+ Revision: 25134
- Remove everything related to old name
- Update to 0.9.8
- Drop old Obsoletes
- imported package upower


* Sat Sep 11 2010 Götz Waschk <waschk@mandriva.org> 0.9.6-0.2mdv2011.0
+ Revision: 577205
- rebuild for new g-i

* Fri Sep 10 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 0.9.6-0.1mdv2011.0
+ Revision: 577135
- patch100: update to current GIT (bump version) to fix upowerd crash

* Fri Jul 30 2010 Funda Wang <fwang@mandriva.org> 0.9.5-2mdv2011.0
+ Revision: 563253
- rebuild for new gobject-introspection

* Mon Jul 19 2010 Götz Waschk <waschk@mandriva.org> 0.9.5-1mdv2011.0
+ Revision: 554906
- update to new version 0.9.5

* Sat Jul 10 2010 Götz Waschk <waschk@mandriva.org> 0.9.4-1mdv2011.0
+ Revision: 550282
- new version
- update file list

* Mon Apr 12 2010 Götz Waschk <waschk@mandriva.org> 0.9.2-1mdv2010.1
+ Revision: 533665
- new version
- fix source URL and name
- improve file list

  + Nicolas Lécureuil <nlecureuil@mandriva.com>
    - Fix URL

* Thu Mar 11 2010 Götz Waschk <waschk@mandriva.org> 0.9.1-2mdv2010.1
+ Revision: 518047
- fix obsoletes
- move typelib to the library package

  + Pascal Terjan <pterjan@mandriva.org>
    - renamed to upower

* Sat Jan 09 2010 Emmanuel Andry <eandry@mandriva.org> 014-1mdv2010.1
+ Revision: 488122
- New version 014

* Thu Dec 31 2009 Emmanuel Andry <eandry@mandriva.org> 013-1mdv2010.1
+ Revision: 484413
- New version 013

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 012-1mdv2010.1
+ Revision: 462139
- update to new version 012

* Mon Sep 14 2009 Götz Waschk <waschk@mandriva.org> 010-2mdv2010.0
+ Revision: 439066
- fix build deps

* Mon Jul 27 2009 Frederic Crozat <fcrozat@mandriva.com> 010-1mdv2010.0
+ Revision: 400627
- Release 010

* Mon Jul 06 2009 Frederik Himpe <fhimpe@mandriva.org> 009-1mdv2010.0
+ Revision: 392982
- Update to new version 009 (now installs udev rules in /lib/udev/rules.d/)

* Thu Jun 04 2009 Götz Waschk <waschk@mandriva.org> 008-2mdv2010.0
+ Revision: 382638
- split out library package
- fix devel dep

* Wed Jun 03 2009 Pascal Terjan <pterjan@mandriva.org> 008-1mdv2010.0
+ Revision: 382420
- Update to 008

* Thu Mar 26 2009 Frederic Crozat <fcrozat@mandriva.com> 006-2mdv2009.1
+ Revision: 361369
- Patch1: fix dbus warnings when using g-p-m

* Thu Mar 05 2009 Frederic Crozat <fcrozat@mandriva.com> 006-1mdv2009.1
+ Revision: 349034
- Release 006
- Patch0 (GIT): fix dbus interface usage for CVE 2008-4311

* Wed Jan 28 2009 Pascal Terjan <pterjan@mandriva.org> 004-2mdv2009.1
+ Revision: 335041
- Lower requirements

* Wed Jan 28 2009 Pascal Terjan <pterjan@mandriva.org> 004-1mdv2009.1
+ Revision: 334967
- import devicekit-power

